"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AddFileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_NAME_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    FULL_PATH_FIELD_NUMBER: builtins.int
    file_name: builtins.str
    hash: builtins.str
    """hash of the file"""
    url: builtins.str
    full_path: builtins.str
    """full_path is the full path of the file on the local filesystem"""
    def __init__(
        self,
        *,
        file_name: builtins.str = ...,
        hash: builtins.str = ...,
        url: builtins.str | None = ...,
        full_path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_url", b"_url", "url", b"url"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_url", b"_url", "file_name", b"file_name", "full_path", b"full_path", "hash", b"hash", "url", b"url"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_url", b"_url"]) -> typing_extensions.Literal["url"] | None: ...

global___AddFileRequest = AddFileRequest

@typing_extensions.final
class CheckText(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_GOOGLE_ON_FIELD_NUMBER: builtins.int
    DOCUMENT_FIELD_NUMBER: builtins.int
    USER_UID_FIELD_NUMBER: builtins.int
    is_google_on: builtins.bool
    document: builtins.str
    user_uid: builtins.str
    def __init__(
        self,
        *,
        is_google_on: builtins.bool = ...,
        document: builtins.str = ...,
        user_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["document", b"document", "is_google_on", b"is_google_on", "user_uid", b"user_uid"]) -> None: ...

global___CheckText = CheckText

@typing_extensions.final
class CheckFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_NAME_FIELD_NUMBER: builtins.int
    USER_UID_FIELD_NUMBER: builtins.int
    IS_GOOGLE_ON_FIELD_NUMBER: builtins.int
    FULL_PATH_FIELD_NUMBER: builtins.int
    file_name: builtins.str
    user_uid: builtins.str
    is_google_on: builtins.bool
    full_path: builtins.str
    def __init__(
        self,
        *,
        file_name: builtins.str = ...,
        user_uid: builtins.str = ...,
        is_google_on: builtins.bool = ...,
        full_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_name", b"file_name", "full_path", b"full_path", "is_google_on", b"is_google_on", "user_uid", b"user_uid"]) -> None: ...

global___CheckFile = CheckFile

@typing_extensions.final
class CheckTextResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class CheckResult(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FILE_HASH_FIELD_NUMBER: builtins.int
        FILE_NAME_FIELD_NUMBER: builtins.int
        PLAGIARISM_PERCENTAGE_FIELD_NUMBER: builtins.int
        EXTENDED_DATA_URL_FIELD_NUMBER: builtins.int
        file_hash: builtins.str
        file_name: builtins.str
        plagiarism_percentage: builtins.float
        extended_data_url: builtins.str
        def __init__(
            self,
            *,
            file_hash: builtins.str = ...,
            file_name: builtins.str = ...,
            plagiarism_percentage: builtins.float = ...,
            extended_data_url: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["extended_data_url", b"extended_data_url", "file_hash", b"file_hash", "file_name", b"file_name", "plagiarism_percentage", b"plagiarism_percentage"]) -> None: ...

    CHECK_RESULT_FIELD_NUMBER: builtins.int
    USER_UID_FIELD_NUMBER: builtins.int
    @property
    def check_result(self) -> global___CheckTextResult.CheckResult: ...
    user_uid: builtins.str
    def __init__(
        self,
        *,
        check_result: global___CheckTextResult.CheckResult | None = ...,
        user_uid: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["check_result", b"check_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["check_result", b"check_result", "user_uid", b"user_uid"]) -> None: ...

global___CheckTextResult = CheckTextResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class HashFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    CONTENT_HASH_FIELD_NUMBER: builtins.int
    WORDS_FIELD_NUMBER: builtins.int
    TEXT_LINK_FIELD_NUMBER: builtins.int
    name: builtins.str
    url: builtins.str
    content_hash: builtins.str
    @property
    def words(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WordAndPosition]: ...
    text_link: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        url: builtins.str = ...,
        content_hash: builtins.str = ...,
        words: collections.abc.Iterable[global___WordAndPosition] | None = ...,
        text_link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_hash", b"content_hash", "name", b"name", "text_link", b"text_link", "url", b"url", "words", b"words"]) -> None: ...

global___HashFile = HashFile

@typing_extensions.final
class WordAndPosition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORD_FIELD_NUMBER: builtins.int
    START_POSITION_FIELD_NUMBER: builtins.int
    END_POSITION_FIELD_NUMBER: builtins.int
    word: builtins.str
    start_position: builtins.int
    end_position: builtins.int
    def __init__(
        self,
        *,
        word: builtins.str = ...,
        start_position: builtins.int = ...,
        end_position: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_position", b"end_position", "start_position", b"start_position", "word", b"word"]) -> None: ...

global___WordAndPosition = WordAndPosition
